@@ -151,7 +151,8 @@ class BufferSwapCompleteEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xH2xIIIIII", self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2xH2xIIIIII", self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc))
         return buf.getvalue()
 _events[0] = BufferSwapCompleteEvent
 class InvalidateBuffersEvent(xcffib.Event):
@@ -162,7 +163,8 @@ class InvalidateBuffersEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xI", self.drawable))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=x2xI", self.drawable))
         return buf.getvalue()
 _events[1] = InvalidateBuffersEvent
 class dri2Extension(xcffib.Extension):
