@@ -15,7 +15,8 @@ class GenericError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", -1))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadGeneric = GenericError
 _errors[-1] = GenericError
@@ -27,7 +28,8 @@ class BadContextError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadContext = BadContextError
 _errors[0] = BadContextError
@@ -39,7 +41,8 @@ class BadContextStateError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadContextState = BadContextStateError
 _errors[1] = BadContextStateError
@@ -51,7 +54,8 @@ class BadDrawableError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 2))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadDrawable = BadDrawableError
 _errors[2] = BadDrawableError
@@ -63,7 +67,8 @@ class BadPixmapError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 3))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadPixmap = BadPixmapError
 _errors[3] = BadPixmapError
@@ -75,7 +80,8 @@ class BadContextTagError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 4))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadContextTag = BadContextTagError
 _errors[4] = BadContextTagError
@@ -87,7 +93,8 @@ class BadCurrentWindowError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 5))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadCurrentWindow = BadCurrentWindowError
 _errors[5] = BadCurrentWindowError
@@ -99,7 +106,8 @@ class BadRenderRequestError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 6))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadRenderRequest = BadRenderRequestError
 _errors[6] = BadRenderRequestError
@@ -111,7 +119,8 @@ class BadLargeRequestError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 7))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadLargeRequest = BadLargeRequestError
 _errors[7] = BadLargeRequestError
@@ -123,7 +132,8 @@ class UnsupportedPrivateRequestError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 8))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadUnsupportedPrivateRequest = UnsupportedPrivateRequestError
 _errors[8] = UnsupportedPrivateRequestError
@@ -135,7 +145,8 @@ class BadFBConfigError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 9))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadFBConfig = BadFBConfigError
 _errors[9] = BadFBConfigError
@@ -147,7 +158,8 @@ class BadPbufferError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 10))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadPbuffer = BadPbufferError
 _errors[10] = BadPbufferError
@@ -159,7 +171,8 @@ class BadCurrentDrawableError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 11))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadCurrentDrawable = BadCurrentDrawableError
 _errors[11] = BadCurrentDrawableError
@@ -171,7 +184,8 @@ class BadWindowError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 12))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadWindow = BadWindowError
 _errors[12] = BadWindowError
@@ -183,7 +197,8 @@ class GLXBadProfileARBError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 13))
+        buf.write(struct.pack("=x2xIHB21x", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadGLXBadProfileARB = GLXBadProfileARBError
 _errors[13] = GLXBadProfileARBError
@@ -195,7 +210,8 @@ class PbufferClobberEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xHHIIHHHHHH4x", self.event_type, self.draw_type, self.drawable, self.b_mask, self.aux_buffer, self.x, self.y, self.width, self.height, self.count))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2xHHIIHHHHHH4x", self.event_type, self.draw_type, self.drawable, self.b_mask, self.aux_buffer, self.x, self.y, self.width, self.height, self.count))
         return buf.getvalue()
 _events[0] = PbufferClobberEvent
 class BufferSwapCompleteEvent(xcffib.Event):
@@ -206,7 +222,8 @@ class BufferSwapCompleteEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xH2xIIIIII", self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=x2xH2xIIIIII", self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc))
         return buf.getvalue()
 _events[1] = BufferSwapCompleteEvent
 class PBCET:
