@@ -73,7 +73,8 @@ class GenericEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIH2xI", self.extension, self.length, self.evtype, self.event))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=B2xIH2xI", self.extension, self.length, self.evtype, self.event))
         return buf.getvalue()
 _events[0] = GenericEvent
 class ConfigureNotifyEvent(xcffib.Event):
@@ -84,7 +85,8 @@ class ConfigureNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=2xIIhhHHhhHHI", self.event, self.window, self.x, self.y, self.width, self.height, self.off_x, self.off_y, self.pixmap_width, self.pixmap_height, self.pixmap_flags))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2x2xIIhhHHhhHHI", self.event, self.window, self.x, self.y, self.width, self.height, self.off_x, self.off_y, self.pixmap_width, self.pixmap_height, self.pixmap_flags))
         return buf.getvalue()
 _events[0] = ConfigureNotifyEvent
 class CompleteNotifyEvent(xcffib.Event):
@@ -95,7 +97,8 @@ class CompleteNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BBIIIQQ", self.kind, self.mode, self.event, self.window, self.serial, self.ust, self.msc))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=B2xBIIIQQ", self.kind, self.mode, self.event, self.window, self.serial, self.ust, self.msc))
         return buf.getvalue()
 _events[1] = CompleteNotifyEvent
 class IdleNotifyEvent(xcffib.Event):
@@ -106,7 +109,8 @@ class IdleNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=2xIIIII", self.event, self.window, self.serial, self.pixmap, self.idle_fence))
+        buf.write(struct.pack("=B", 2))
+        buf.write(struct.pack("=x2x2xIIIII", self.event, self.window, self.serial, self.pixmap, self.idle_fence))
         return buf.getvalue()
 _events[2] = IdleNotifyEvent
 class RedirectNotifyEvent(xcffib.Event):
@@ -123,7 +127,8 @@ class RedirectNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BxIIIIIIIhhIIII4xQQQ", self.update_window, self.event, self.event_window, self.window, self.pixmap, self.serial, self.valid_region, self.update_region, self.x_off, self.y_off, self.target_crtc, self.wait_fence, self.idle_fence, self.options, self.target_msc, self.divisor, self.remainder))
+        buf.write(struct.pack("=B", 3))
+        buf.write(struct.pack("=B2xxIIIIIIIhhIIII4xQQQ", self.update_window, self.event, self.event_window, self.window, self.pixmap, self.serial, self.valid_region, self.update_region, self.x_off, self.y_off, self.target_crtc, self.wait_fence, self.idle_fence, self.options, self.target_msc, self.divisor, self.remainder))
         buf.write(self.valid_rect.pack())
         buf.write(self.update_rect.pack())
         buf.write(xcffib.pack_list(self.notifies, Notify))
