@@ -352,7 +352,8 @@ class ScreenChangeNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIHHHHHH", self.rotation, self.timestamp, self.config_timestamp, self.root, self.request_window, self.sizeID, self.subpixel_order, self.width, self.height, self.mwidth, self.mheight))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=B2xIIIIHHHHHH", self.rotation, self.timestamp, self.config_timestamp, self.root, self.request_window, self.sizeID, self.subpixel_order, self.width, self.height, self.mwidth, self.mheight))
         return buf.getvalue()
 _events[0] = ScreenChangeNotifyEvent
 class Notify:
@@ -437,6 +438,10 @@ class NotifyData(xcffib.Union):
         self.pc = ProviderChange(unpacker.copy())
         self.pp = ProviderProperty(unpacker.copy())
         self.rc = ResourceChange(unpacker.copy())
+    def pack(self):
+        buf = six.BytesIO()
+        buf.write(self.cc.pack())
+        return buf.getvalue()
 class NotifyEvent(xcffib.Event):
     def __init__(self, unpacker):
         xcffib.Event.__init__(self, unpacker)
@@ -446,7 +451,8 @@ class NotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=B", self.subCode))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=B2x", self.subCode))
         buf.write(self.u.pack())
         return buf.getvalue()
 _events[1] = NotifyEvent
