@@ -43,7 +43,8 @@ class NotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIBB14x", self.state, self.time, self.root, self.window, self.kind, self.forced))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=B2xIIIBB14x", self.state, self.time, self.root, self.window, self.kind, self.forced))
         return buf.getvalue()
 _events[0] = NotifyEvent
 class screensaverExtension(xcffib.Extension):
