@@ -15,7 +15,8 @@ class CompletionEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIHBxII", self.drawable, self.minor_event, self.major_event, self.shmseg, self.offset))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2xIHBxII", self.drawable, self.minor_event, self.major_event, self.shmseg, self.offset))
         return buf.getvalue()
 _events[0] = CompletionEvent
 class BadSegError(xcffib.Error):
@@ -26,7 +27,8 @@ class BadSegError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadBadSeg = BadSegError
 _errors[0] = BadSegError
