@@ -225,7 +225,8 @@ class KeyPressEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
+        buf.write(struct.pack("=B", 2))
+        buf.write(struct.pack("=B2xIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
         return buf.getvalue()
 _events[2] = KeyPressEvent
 class KeyReleaseEvent(xcffib.Event):
@@ -236,7 +237,8 @@ class KeyReleaseEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
+        buf.write(struct.pack("=B", 3))
+        buf.write(struct.pack("=B2xIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
         return buf.getvalue()
 _events[3] = KeyReleaseEvent
 class ButtonMask:
@@ -254,7 +256,8 @@ class ButtonPressEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
+        buf.write(struct.pack("=B", 4))
+        buf.write(struct.pack("=B2xIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
         return buf.getvalue()
 _events[4] = ButtonPressEvent
 class ButtonReleaseEvent(xcffib.Event):
@@ -265,7 +268,8 @@ class ButtonReleaseEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
+        buf.write(struct.pack("=B", 5))
+        buf.write(struct.pack("=B2xIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
         return buf.getvalue()
 _events[5] = ButtonReleaseEvent
 class Motion:
@@ -279,7 +283,8 @@ class MotionNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
+        buf.write(struct.pack("=B", 6))
+        buf.write(struct.pack("=B2xIIIIhhhhHBx", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.same_screen))
         return buf.getvalue()
 _events[6] = MotionNotifyEvent
 class NotifyDetail:
@@ -304,7 +309,8 @@ class EnterNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBB", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.mode, self.same_screen_focus))
+        buf.write(struct.pack("=B", 7))
+        buf.write(struct.pack("=B2xIIIIhhhhHBB", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.mode, self.same_screen_focus))
         return buf.getvalue()
 _events[7] = EnterNotifyEvent
 class LeaveNotifyEvent(xcffib.Event):
@@ -315,7 +321,8 @@ class LeaveNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIIhhhhHBB", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.mode, self.same_screen_focus))
+        buf.write(struct.pack("=B", 8))
+        buf.write(struct.pack("=B2xIIIIhhhhHBB", self.detail, self.time, self.root, self.event, self.child, self.root_x, self.root_y, self.event_x, self.event_y, self.state, self.mode, self.same_screen_focus))
         return buf.getvalue()
 _events[8] = LeaveNotifyEvent
 class FocusInEvent(xcffib.Event):
@@ -326,7 +333,8 @@ class FocusInEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIB3x", self.detail, self.event, self.mode))
+        buf.write(struct.pack("=B", 9))
+        buf.write(struct.pack("=B2xIB3x", self.detail, self.event, self.mode))
         return buf.getvalue()
 _events[9] = FocusInEvent
 class FocusOutEvent(xcffib.Event):
@@ -337,7 +345,8 @@ class FocusOutEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIB3x", self.detail, self.event, self.mode))
+        buf.write(struct.pack("=B", 10))
+        buf.write(struct.pack("=B2xIB3x", self.detail, self.event, self.mode))
         return buf.getvalue()
 _events[10] = FocusOutEvent
 class KeymapNotifyEvent(xcffib.Event):
@@ -349,6 +358,7 @@ class KeymapNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
+        buf.write(struct.pack("=B", 11))
         buf.write(xcffib.pack_list(self.keys, "B"))
         return buf.getvalue()
 _events[11] = KeymapNotifyEvent
@@ -360,7 +370,8 @@ class ExposeEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIHHHHH2x", self.window, self.x, self.y, self.width, self.height, self.count))
+        buf.write(struct.pack("=B", 12))
+        buf.write(struct.pack("=x2xIHHHHH2x", self.window, self.x, self.y, self.width, self.height, self.count))
         return buf.getvalue()
 _events[12] = ExposeEvent
 class GraphicsExposureEvent(xcffib.Event):
@@ -371,7 +382,8 @@ class GraphicsExposureEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIHHHHHHB3x", self.drawable, self.x, self.y, self.width, self.height, self.minor_opcode, self.count, self.major_opcode))
+        buf.write(struct.pack("=B", 13))
+        buf.write(struct.pack("=x2xIHHHHHHB3x", self.drawable, self.x, self.y, self.width, self.height, self.minor_opcode, self.count, self.major_opcode))
         return buf.getvalue()
 _events[13] = GraphicsExposureEvent
 class NoExposureEvent(xcffib.Event):
@@ -382,7 +394,8 @@ class NoExposureEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIHBx", self.drawable, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 14))
+        buf.write(struct.pack("=x2xIHBx", self.drawable, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 _events[14] = NoExposureEvent
 class Visibility:
@@ -397,7 +410,8 @@ class VisibilityNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIB3x", self.window, self.state))
+        buf.write(struct.pack("=B", 15))
+        buf.write(struct.pack("=x2xIB3x", self.window, self.state))
         return buf.getvalue()
 _events[15] = VisibilityNotifyEvent
 class CreateNotifyEvent(xcffib.Event):
@@ -408,7 +422,8 @@ class CreateNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIhhHHHBx", self.parent, self.window, self.x, self.y, self.width, self.height, self.border_width, self.override_redirect))
+        buf.write(struct.pack("=B", 16))
+        buf.write(struct.pack("=x2xIIhhHHHBx", self.parent, self.window, self.x, self.y, self.width, self.height, self.border_width, self.override_redirect))
         return buf.getvalue()
 _events[16] = CreateNotifyEvent
 class DestroyNotifyEvent(xcffib.Event):
@@ -419,7 +434,8 @@ class DestroyNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xII", self.event, self.window))
+        buf.write(struct.pack("=B", 17))
+        buf.write(struct.pack("=x2xII", self.event, self.window))
         return buf.getvalue()
 _events[17] = DestroyNotifyEvent
 class UnmapNotifyEvent(xcffib.Event):
@@ -430,7 +446,8 @@ class UnmapNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIB3x", self.event, self.window, self.from_configure))
+        buf.write(struct.pack("=B", 18))
+        buf.write(struct.pack("=x2xIIB3x", self.event, self.window, self.from_configure))
         return buf.getvalue()
 _events[18] = UnmapNotifyEvent
 class MapNotifyEvent(xcffib.Event):
@@ -441,7 +458,8 @@ class MapNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIB3x", self.event, self.window, self.override_redirect))
+        buf.write(struct.pack("=B", 19))
+        buf.write(struct.pack("=x2xIIB3x", self.event, self.window, self.override_redirect))
         return buf.getvalue()
 _events[19] = MapNotifyEvent
 class MapRequestEvent(xcffib.Event):
@@ -452,7 +470,8 @@ class MapRequestEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xII", self.parent, self.window))
+        buf.write(struct.pack("=B", 20))
+        buf.write(struct.pack("=x2xII", self.parent, self.window))
         return buf.getvalue()
 _events[20] = MapRequestEvent
 class ReparentNotifyEvent(xcffib.Event):
@@ -463,7 +482,8 @@ class ReparentNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIhhB3x", self.event, self.window, self.parent, self.x, self.y, self.override_redirect))
+        buf.write(struct.pack("=B", 21))
+        buf.write(struct.pack("=x2xIIIhhB3x", self.event, self.window, self.parent, self.x, self.y, self.override_redirect))
         return buf.getvalue()
 _events[21] = ReparentNotifyEvent
 class ConfigureNotifyEvent(xcffib.Event):
@@ -474,7 +494,8 @@ class ConfigureNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIhhHHHBx", self.event, self.window, self.above_sibling, self.x, self.y, self.width, self.height, self.border_width, self.override_redirect))
+        buf.write(struct.pack("=B", 22))
+        buf.write(struct.pack("=x2xIIIhhHHHBx", self.event, self.window, self.above_sibling, self.x, self.y, self.width, self.height, self.border_width, self.override_redirect))
         return buf.getvalue()
 _events[22] = ConfigureNotifyEvent
 class ConfigureRequestEvent(xcffib.Event):
@@ -485,7 +506,8 @@ class ConfigureRequestEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIIIhhHHHH", self.stack_mode, self.parent, self.window, self.sibling, self.x, self.y, self.width, self.height, self.border_width, self.value_mask))
+        buf.write(struct.pack("=B", 23))
+        buf.write(struct.pack("=B2xIIIhhHHHH", self.stack_mode, self.parent, self.window, self.sibling, self.x, self.y, self.width, self.height, self.border_width, self.value_mask))
         return buf.getvalue()
 _events[23] = ConfigureRequestEvent
 class GravityNotifyEvent(xcffib.Event):
@@ -496,7 +518,8 @@ class GravityNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIhh", self.event, self.window, self.x, self.y))
+        buf.write(struct.pack("=B", 24))
+        buf.write(struct.pack("=x2xIIhh", self.event, self.window, self.x, self.y))
         return buf.getvalue()
 _events[24] = GravityNotifyEvent
 class ResizeRequestEvent(xcffib.Event):
@@ -507,7 +530,8 @@ class ResizeRequestEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIHH", self.window, self.width, self.height))
+        buf.write(struct.pack("=B", 25))
+        buf.write(struct.pack("=x2xIHH", self.window, self.width, self.height))
         return buf.getvalue()
 _events[25] = ResizeRequestEvent
 class Place:
@@ -521,7 +545,8 @@ class CirculateNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xII4xB3x", self.event, self.window, self.place))
+        buf.write(struct.pack("=B", 26))
+        buf.write(struct.pack("=x2xII4xB3x", self.event, self.window, self.place))
         return buf.getvalue()
 _events[26] = CirculateNotifyEvent
 class CirculateRequestEvent(xcffib.Event):
@@ -532,7 +557,8 @@ class CirculateRequestEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xII4xB3x", self.event, self.window, self.place))
+        buf.write(struct.pack("=B", 27))
+        buf.write(struct.pack("=x2xII4xB3x", self.event, self.window, self.place))
         return buf.getvalue()
 _events[27] = CirculateRequestEvent
 class Property:
@@ -546,7 +572,8 @@ class PropertyNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIB3x", self.window, self.atom, self.time, self.state))
+        buf.write(struct.pack("=B", 28))
+        buf.write(struct.pack("=x2xIIIB3x", self.window, self.atom, self.time, self.state))
         return buf.getvalue()
 _events[28] = PropertyNotifyEvent
 class SelectionClearEvent(xcffib.Event):
@@ -557,7 +584,8 @@ class SelectionClearEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIII", self.time, self.owner, self.selection))
+        buf.write(struct.pack("=B", 29))
+        buf.write(struct.pack("=x2xIII", self.time, self.owner, self.selection))
         return buf.getvalue()
 _events[29] = SelectionClearEvent
 class Time:
@@ -641,7 +669,8 @@ class SelectionRequestEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIIII", self.time, self.owner, self.requestor, self.selection, self.target, self.property))
+        buf.write(struct.pack("=B", 30))
+        buf.write(struct.pack("=x2xIIIIII", self.time, self.owner, self.requestor, self.selection, self.target, self.property))
         return buf.getvalue()
 _events[30] = SelectionRequestEvent
 class SelectionNotifyEvent(xcffib.Event):
@@ -652,7 +681,8 @@ class SelectionNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIII", self.time, self.requestor, self.selection, self.target, self.property))
+        buf.write(struct.pack("=B", 31))
+        buf.write(struct.pack("=x2xIIIII", self.time, self.requestor, self.selection, self.target, self.property))
         return buf.getvalue()
 _events[31] = SelectionNotifyEvent
 class ColormapState:
@@ -668,7 +698,8 @@ class ColormapNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIBB2x", self.window, self.colormap, self.new, self.state))
+        buf.write(struct.pack("=B", 32))
+        buf.write(struct.pack("=x2xIIBB2x", self.window, self.colormap, self.new, self.state))
         return buf.getvalue()
 _events[32] = ColormapNotifyEvent
 class ClientMessageData(xcffib.Union):
@@ -677,6 +708,10 @@ class ClientMessageData(xcffib.Union):
         self.data8 = xcffib.List(unpacker.copy(), "B", 20)
         self.data16 = xcffib.List(unpacker.copy(), "H", 10)
         self.data32 = xcffib.List(unpacker.copy(), "I", 5)
+    def pack(self):
+        buf = six.BytesIO()
+        buf.write(xcffib.pack_list(self.data8, "B"))
+        return buf.getvalue()
 class ClientMessageEvent(xcffib.Event):
     def __init__(self, unpacker):
         xcffib.Event.__init__(self, unpacker)
@@ -686,7 +721,8 @@ class ClientMessageEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BII", self.format, self.window, self.type))
+        buf.write(struct.pack("=B", 33))
+        buf.write(struct.pack("=B2xII", self.format, self.window, self.type))
         buf.write(self.data.pack())
         return buf.getvalue()
 _events[33] = ClientMessageEvent
@@ -702,7 +738,8 @@ class MappingNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xBBBx", self.request, self.first_keycode, self.count))
+        buf.write(struct.pack("=B", 34))
+        buf.write(struct.pack("=x2xBBBx", self.request, self.first_keycode, self.count))
         return buf.getvalue()
 _events[34] = MappingNotifyEvent
 class GeGenericEvent(xcffib.Event):
@@ -713,7 +750,8 @@ class GeGenericEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=22x"))
+        buf.write(struct.pack("=B", 35))
+        buf.write(struct.pack("=x2x22x"))
         return buf.getvalue()
 _events[35] = GeGenericEvent
 class RequestError(xcffib.Error):
@@ -724,7 +762,8 @@ class RequestError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadRequest = RequestError
 _errors[1] = RequestError
@@ -736,7 +775,8 @@ class ValueError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 2))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadValue = ValueError
 _errors[2] = ValueError
@@ -748,7 +788,8 @@ class WindowError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 3))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadWindow = WindowError
 _errors[3] = WindowError
@@ -760,7 +801,8 @@ class PixmapError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 4))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadPixmap = PixmapError
 _errors[4] = PixmapError
@@ -772,7 +814,8 @@ class AtomError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 5))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadAtom = AtomError
 _errors[5] = AtomError
@@ -784,7 +827,8 @@ class CursorError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 6))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadCursor = CursorError
 _errors[6] = CursorError
@@ -796,7 +840,8 @@ class FontError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 7))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadFont = FontError
 _errors[7] = FontError
@@ -808,7 +853,8 @@ class MatchError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 8))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadMatch = MatchError
 _errors[8] = MatchError
@@ -820,7 +866,8 @@ class DrawableError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 9))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadDrawable = DrawableError
 _errors[9] = DrawableError
@@ -832,7 +879,8 @@ class AccessError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 10))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadAccess = AccessError
 _errors[10] = AccessError
@@ -844,7 +892,8 @@ class AllocError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 11))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadAlloc = AllocError
 _errors[11] = AllocError
@@ -856,7 +905,8 @@ class ColormapError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 12))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadColormap = ColormapError
 _errors[12] = ColormapError
@@ -868,7 +918,8 @@ class GContextError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 13))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadGContext = GContextError
 _errors[13] = GContextError
@@ -880,7 +931,8 @@ class IDChoiceError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 14))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadIDChoice = IDChoiceError
 _errors[14] = IDChoiceError
@@ -892,7 +944,8 @@ class NameError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 15))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadName = NameError
 _errors[15] = NameError
@@ -904,7 +957,8 @@ class LengthError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 16))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadLength = LengthError
 _errors[16] = LengthError
@@ -916,7 +970,8 @@ class ImplementationError(xcffib.Error):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=IHBx", self.bad_value, self.minor_opcode, self.major_opcode))
+        buf.write(struct.pack("=B", 17))
+        buf.write(struct.pack("=x2xIHBx", self.bad_value, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
 BadImplementation = ImplementationError
 _errors[17] = ImplementationError
