@@ -147,7 +147,8 @@ class VideoNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=BIII", self.reason, self.time, self.drawable, self.port))
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=B2xIII", self.reason, self.time, self.drawable, self.port))
         return buf.getvalue()
 _events[0] = VideoNotifyEvent
 class PortNotifyEvent(xcffib.Event):
@@ -158,7 +159,8 @@ class PortNotifyEvent(xcffib.Event):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = six.BytesIO()
-        buf.write(struct.pack("=xIIIi", self.time, self.port, self.attribute, self.value))
+        buf.write(struct.pack("=B", 1))
+        buf.write(struct.pack("=x2xIIIi", self.time, self.port, self.attribute, self.value))
         return buf.getvalue()
 _events[1] = PortNotifyEvent
 class QueryExtensionReply(xcffib.Reply):
